// $Id: RETestAction.java,v 1.1.1.1 2000/12/18 16:37:55 sjakob Exp $
/*
 * RETestAction.java - The EditAction called after selecting "RE Tester"
 * from the jEdit "Plugins" menu. Only responsible for displaying the
 * RETestView object.
 * Copyright (C) 2000 Steve Jakob
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import org.gjt.sp.jedit.*;
// import org.gjt.sp.util.Log;

/**
* This class is designed for use with jEdit and will insert a code
* template at the current position within the current document.
* @author Steve Jakob
*/
public class RETestAction extends EditAction
{
	private RETestControl reControl = null;

	public RETestAction()
	{
		super("RETestAction");
	}

	/**
	 * Called when the user selects the "RE Tester" from the "Plugins" menu. 
	 * Create the RE test controller, if necessary, and display the test dialog.
	 * @param evt The ActionEvent generated by the menu selection.
	 */
	public void actionPerformed(java.awt.event.ActionEvent evt)
	{
		// If the RE test controller is not yet created, then create it
		if (reControl == null) {
			reControl = new RETestControl();
			reControl.setJeditView(getView(evt));
		}
		reControl.displayView();		// Display the test dialog
	}
}

	/*
	 * Change Log:
	 * $Log: RETestAction.java,v $
	 * Revision 1.1.1.1  2000/12/18 16:37:55  sjakob
	 * Initial import.
	 * Bug fix release for Character Classes (eg. [[:alpha:]]) problem.
	 *
	 * Revision 1.4  2000/02/04 20:31:09  sjakob
	 * Decoupled controller from RETestView class.
	 *
	 * Revision 1.3  2000/01/27 22:10:14  sjakob
	 * Added support for inserting RE into current buffer.
	 *
	 * Revision 1.2  2000/01/24 21:50:57  sjakob
	 * Added plugin help page, RE syntax help page.
	 * Moved hard-coded strings to properties file.
	 * Minor cosmetic changes to Javadoc comments.
	 *
	 * Revision 1.1  2000/01/19 22:03:39  sjakob
	 * Release Candidate 1.
	 *
	 */

